// KreateCD - CD recording software for the K desktop environment
//
// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
//
// This file is subject to the terms and conditions of the GNU General      
// Public License.  See the file COPYING in the main directory of the       
// KreateCD distribution for more details.                                     

#include <qwidget.h>
#include <qdialog.h>
#include <qstring.h>

class LineDialog : public QDialog
 {
  Q_OBJECT;

  public:
    LineDialog( QWidget *parent=0, const char *name=0, const char *startstring=0);
    ~LineDialog(void);

    const char *getInput(void);

  protected slots:
    void leaveDialog(void);

  private:
#if QT_VERSION >= 200
    class KLineEdit *EditWidget;
#else
    class KLined *EditWidget;
#endif
 };


